<script id="tmpl-nf-field-color" type="text/template">
	<input id="nf-field-{{{ data.id }}}" name="nf-field-{{{ data.id }}}" aria-invalid="false" aria-describedby="nf-error-{{{ data.id }}}" class="{{{ data.classes }}} nf-element" type="color" value="{{{ data.value }}}" {{{ data.renderPlaceholder() }}}>
</script>
