<script id="tmpl-nf-field-total" type="text/template">
    <span id="nf-field-{{{ data.id }}}" name="nf-field-{{{ data.id }}}" class="nf-static {{{ data.renderClasses() }}} nf-element">{{{ data.renderCurrencyFormatting( data.value ) }}}</span>
</script>
