<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'NinjaForms\\Blocks\\Authentication\\KeyFactory' => $baseDir . '/blocks/views/includes/Authentication/KeyFactory.php',
    'NinjaForms\\Blocks\\Authentication\\SecretStore' => $baseDir . '/blocks/views/includes/Authentication/SecretStore.php',
    'NinjaForms\\Blocks\\Authentication\\Token' => $baseDir . '/blocks/views/includes/Authentication/Token.php',
    'NinjaForms\\Blocks\\Authentication\\TokenFactory' => $baseDir . '/blocks/views/includes/Authentication/TokenFactory.php',
    'NinjaForms\\Blocks\\DataBuilder\\FieldsBuilder' => $baseDir . '/blocks/views/includes/DataBuilder/FieldsBuilder.php',
    'NinjaForms\\Blocks\\DataBuilder\\FieldsBuilderFactory' => $baseDir . '/blocks/views/includes/DataBuilder/FieldsBuilderFactory.php',
    'NinjaForms\\Blocks\\DataBuilder\\FormsBuilder' => $baseDir . '/blocks/views/includes/DataBuilder/FormsBuilder.php',
    'NinjaForms\\Blocks\\DataBuilder\\FormsBuilderFactory' => $baseDir . '/blocks/views/includes/DataBuilder/FormsBuilderFactory.php',
    'NinjaForms\\Blocks\\DataBuilder\\SubmissionsBuilder' => $baseDir . '/blocks/views/includes/DataBuilder/SubmissionsBuilder.php',
    'NinjaForms\\Blocks\\DataBuilder\\SubmissionsBuilderFactory' => $baseDir . '/blocks/views/includes/DataBuilder/SubmissionsBuilderFactory.php',
);
