<div id="nf-menu-drawer">
    <ul>
        <li class="nf-publish"><?php esc_html_e( 'Publish', 'ninja-forms' ); ?></li>
    </ul>
    <ul>
        <li><a href="#"><span class="dashicons dashicons-menu"></span><?php esc_html_e( 'Form Fields', 'ninja-forms' ); ?></a></li>
        <li><a href="http://three.ninjaforms.com/wp-admin/admin.php?page=edit-action"><span class="dashicons dashicons-external"></span><?php esc_html_e( 'Emails & Actions', 'ninja-forms' ); ?></a></li>
        <li><a href="#"><span class="dashicons dashicons-admin-generic"></span><?php esc_html_e( 'Settings', 'ninja-forms' ); ?></a></li>
        <li><a href="#"><span class="dashicons dashicons-visibility"></span><?php esc_html_e( 'Preview', 'ninja-forms' ); ?></a></li>
    </ul>
</div>
