/* ---------------------------------
/  Generic styles & classes
----------------------------------*/
.nf-box {
    background: #fff;
    border: 1px solid #ccc;
    border-radius: 4px;
    padding: 10px;
}

.nf-extend {
    float: left;
    margin: 0 20px 20px 0;
    width: 300px;
    position: relative;
}
.nf-extend img {
    margin-bottom: 10px;
    max-width: 100%;
    height: auto;
}

.nf-extend h2 {
    white-space: nowrap;
    overflow: hidden;
}

.nf-extend-content p {
    min-height: 60px;
}

.nf-extend .nf-button {
    float: right;
}

.nf-extend .nf-doc-button {
    float: left;
}

.mp6 .nf-extend {
    background: #fff;
    border: 1px solid #ccc;
    border-radius: 4px;
    float: left;
    margin: 0 20px 20px 0;
    padding: 10px;
    position: relative;
    width: 300px;
    height: 350px;
}
.branch-3-8 .nf-extend {
    background: #fff;
}
