.nf-help{background:none}.nf-field-description{font-size:14px}.nf-form-content{padding:5px;max-width:1000px;margin:0 auto}.nf-form-content label{font-size:18px;line-height:20px}.nf-form-content .listselect-wrap .nf-field-element div,.nf-form-content .ninja-forms-field{font-size:16px;margin:0;padding:12px}.nf-form-content .listselect-wrap .nf-field-element div,.nf-form-content input.ninja-forms-field,.nf-form-content select.ninja-forms-field:not([multiple]){height:50px}.nf-form-content textarea.ninja-forms-field{height:200px}.nf-form-content hr.ninja-forms-field{padding:0}.nf-form-content input[type=checkbox].ninja-forms-field,.nf-form-content input[type=radio].ninja-forms-field{height:auto}.nf-form-content .listcheckbox-wrap li,.nf-form-content .listradio-wrap li{margin-bottom:12px!important;line-height:0}.nf-form-content .nf-product-field span{padding-right:16px}.nf-form-content .nf-product-field .nf-field-qty{font-size:16px;padding:5px;width:80px!important}.nf-form-content .nf-static{background:transparent;border:0;font-weight:700;padding:0}.nf-form-content .label-above .nf-field-label,.nf-form-content .label-below .nf-field-label,.nf-form-content .label-hidden .nf-field-label{margin-bottom:10px;padding:0}.nf-form-content .label-below .nf-field-label{margin-bottom:0;margin-top:10px}.nf-form-content .label-right .nf-field-label{margin:0}.nf-form-content .label-right>input[type=radio],.nf-form-content .label-right input[type=checkbox],.nf-form-content .label-right ul{margin-right:1%}.five-sixths,.four-sixths,.one-fourth,.one-half,.one-sixth,.one-third,.three-fourths,.three-sixths,.two-fourths,.two-sixths,.two-thirds{clear:none;float:left;margin-left:2.564102564102564%}.five-sixths .inside,.four-sixths .inside,.one-fourth .inside,.one-half .inside,.one-sixth .inside,.one-third .inside,.three-fourths .inside,.three-sixths .inside,.two-fourths .inside,.two-sixths .inside,.two-thirds .inside{padding:20px}.five-sixths:after,.four-sixths:after,.one-fourth:after,.one-half:after,.one-sixth:after,.one-third:after,.three-fourths:after,.three-sixths:after,.two-fourths:after,.two-sixths:after,.two-thirds:after{clear:both;content:"";display:block}.one-half,.three-sixths,.two-fourths{width:48.717948717948715%}.one-third,.two-sixths{width:31.623931623931625%}.four-sixths,.two-thirds{width:65.81196581196582%}.one-fourth{width:23.076923076923077%}.three-fourths{width:74.35897435897436%}.one-sixth{width:14.52991452991453%}.five-sixths{width:82.90598290598291%}.first{clear:both;margin-left:0}input[type=checkbox].nf-toggle{background:transparent;border:0;box-shadow:0 0 0;margin:10px;height:18px;-webkit-appearance:none;appearance:none;position:relative;cursor:pointer}input[type=checkbox].nf-toggle:after{background:#bcbdbf;border:2px solid #bcbdbf;border-radius:20px;content:"";position:absolute;top:-4px;left:-4px;width:46px;height:24px;transition:all 0.3s ease}input[type=checkbox].nf-toggle:before{background:#fff;border-radius:20px;content:"";position:absolute;top:-1px;left:0;width:18px;height:18px;z-index:99;transition:all 0.3s ease}input[type=checkbox].nf-toggle:checked:after{background:#90ee90;border:2px solid #90ee90;transition:all 0.3s ease}input[type=checkbox].nf-toggle:checked:before{top:-1px;left:20px;transition:all 0.3s ease}.label-right input[type=checkbox].nf-toggle{padding:0 50px 0 0}.label-left input[type=checkbox].nf-toggle{padding:0;margin-left:22px;margin-top:20px}
/*# sourceMappingURL=display-opinions.css.map */
