<ul class="nf-drawer-buttons">
    <li class="nf-drawer-delete"><span class="dashicons dashicons-dismiss"></span><?php esc_html_e( 'Delete', 'ninja-forms' ); ?></li>
    <li class="nf-drawer-duplicate"><span class="dashicons dashicons-admin-page"></span><?php esc_html_e( 'Duplicate', 'ninja-forms' ); ?></li>
</ul>
