<script id="tmpl-nf-field-starrating" type="text/template">
	<span class="starrating" aria-describedby="nf-error-{{{ data.id }}}">
		{{{ data.renderRatings() }}}
    </span>
</script>

<script id="tmpl-nf-field-starrating-star" type="text/template">
	<input type="radio" name="nf-field-{{{ data.id }}}"
	       class="{{{ data.classes }}} nf-element" value="{{{ data.num }}}"
	       {{{ data.checked }}}
            <# if( data.required ) { #>
			required
			<# } #>
	/>
</script>
