<?php if ( ! defined( 'ABSPATH' ) ) exit;

return apply_filters( 'ninja_forms_config_country_list', array(

    /**
     * Country List
     *
     * @since 2.2.28
     */

    esc_attr__( 'Afghanistan', 'ninja-forms' ) => 'AF',
    esc_attr__( 'Albania', 'ninja-forms' ) => 'AL',
    esc_attr__( 'Algeria', 'ninja-forms' ) => 'DZ',
    esc_attr__( 'American Samoa', 'ninja-forms' ) => 'AS',
    esc_attr__( 'Andorra', 'ninja-forms' ) => 'AD',
    esc_attr__( 'Angola', 'ninja-forms' ) => 'AO',
    esc_attr__( 'Anguilla', 'ninja-forms' ) => 'AI',
    esc_attr__( 'Antarctica', 'ninja-forms' ) => 'AQ',
    esc_attr__( 'Antigua And Barbuda', 'ninja-forms' ) => 'AG',
    esc_attr__( 'Argentina', 'ninja-forms' ) => 'AR',
    esc_attr__( 'Armenia', 'ninja-forms' ) => 'AM',
    esc_attr__( 'Aruba', 'ninja-forms' ) => 'AW',
    esc_attr__( 'Australia', 'ninja-forms' ) => 'AU',
    esc_attr__( 'Austria', 'ninja-forms' ) => 'AT',
    esc_attr__( 'Azerbaijan', 'ninja-forms' ) => 'AZ',
    esc_attr__( 'Bahamas', 'ninja-forms' ) => 'BS',
    esc_attr__( 'Bahrain', 'ninja-forms' ) => 'BH',
    esc_attr__( 'Bangladesh', 'ninja-forms' ) => 'BD',
    esc_attr__( 'Barbados', 'ninja-forms' ) => 'BB',
    esc_attr__( 'Belarus', 'ninja-forms' ) => 'BY',
    esc_attr__( 'Belgium', 'ninja-forms' ) => 'BE',
    esc_attr__( 'Belize', 'ninja-forms' ) => 'BZ',
    esc_attr__( 'Benin', 'ninja-forms' ) => 'BJ',
    esc_attr__( 'Bermuda', 'ninja-forms' ) => 'BM',
    esc_attr__( 'Bhutan', 'ninja-forms' ) => 'BT',
    esc_attr__( 'Bolivia', 'ninja-forms' ) => 'BO',
    esc_attr__( 'Bosnia And Herzegowina', 'ninja-forms' ) => 'BA',
    esc_attr__( 'Botswana', 'ninja-forms' ) => 'BW',
    esc_attr__( 'Bouvet Island', 'ninja-forms' ) => 'BV',
    esc_attr__( 'Brazil', 'ninja-forms' ) => 'BR',
    esc_attr__( 'British Indian Ocean Territory', 'ninja-forms' ) => 'IO',
    esc_attr__( 'Brunei Darussalam', 'ninja-forms' ) => 'BN',
    esc_attr__( 'Bulgaria', 'ninja-forms' ) => 'BG',
    esc_attr__( 'Burkina Faso', 'ninja-forms' ) => 'BF',
    esc_attr__( 'Burundi', 'ninja-forms' ) => 'BI',
    esc_attr__( 'Cambodia', 'ninja-forms' ) => 'KH',
    esc_attr__( 'Cameroon', 'ninja-forms' ) => 'CM',
    esc_attr__( 'Canada', 'ninja-forms' ) => 'CA',
    esc_attr__( 'Cape Verde', 'ninja-forms' ) => 'CV',
    esc_attr__( 'Cayman Islands', 'ninja-forms' ) => 'KY',
    esc_attr__( 'Central African Republic', 'ninja-forms' ) => 'CF',
    esc_attr__( 'Chad', 'ninja-forms' ) => 'TD',
    esc_attr__( 'Chile', 'ninja-forms' ) => 'CL',
    esc_attr__( 'China', 'ninja-forms' ) => 'CN',
    esc_attr__( 'Christmas Island', 'ninja-forms' ) => 'CX',
    esc_attr__( 'Cocos (Keeling) Islands', 'ninja-forms' ) => 'CC',
    esc_attr__( 'Colombia', 'ninja-forms' ) => 'CO',
    esc_attr__( 'Comoros', 'ninja-forms' ) => 'KM',
    esc_attr__( 'Congo', 'ninja-forms' ) => 'CG',
    esc_attr__( 'Congo, The Democratic Republic Of The', 'ninja-forms' ) => 'CD',
    esc_attr__( 'Cook Islands', 'ninja-forms' ) => 'CK',
    esc_attr__( 'Costa Rica', 'ninja-forms' ) => 'CR',
    esc_attr__( 'Cote D\'Ivoire', 'ninja-forms' ) => 'CI',
    esc_attr__( 'Croatia (Local Name: Hrvatska)', 'ninja-forms' ) => 'HR',
    esc_attr__( 'Cuba', 'ninja-forms' ) => 'CU',
    esc_attr__( 'Cyprus', 'ninja-forms' ) => 'CY',
    esc_attr__( 'Czech Republic', 'ninja-forms' ) => 'CZ',
    esc_attr__( 'Denmark', 'ninja-forms' ) => 'DK',
    esc_attr__( 'Djibouti', 'ninja-forms' ) => 'DJ',
    esc_attr__( 'Dominica', 'ninja-forms' ) => 'DM',
    esc_attr__( 'Dominican Republic', 'ninja-forms' ) => 'DO',
    esc_attr__( 'Timor-Leste (East Timor)', 'ninja-forms' ) => 'TL',
    esc_attr__( 'Ecuador', 'ninja-forms' ) => 'EC',
    esc_attr__( 'Egypt', 'ninja-forms' ) => 'EG',
    esc_attr__( 'El Salvador', 'ninja-forms' ) => 'SV',
    esc_attr__( 'Equatorial Guinea', 'ninja-forms' ) => 'GQ',
    esc_attr__( 'Eritrea', 'ninja-forms' ) => 'ER',
    esc_attr__( 'Estonia', 'ninja-forms' ) => 'EE',
    esc_attr__( 'Ethiopia', 'ninja-forms' ) => 'ET',
    esc_attr__( 'Falkland Islands (Malvinas)', 'ninja-forms' ) => 'FK',
    esc_attr__( 'Faroe Islands', 'ninja-forms' ) => 'FO',
    esc_attr__( 'Fiji', 'ninja-forms' ) => 'FJ',
    esc_attr__( 'Finland', 'ninja-forms' ) => 'FI',
    esc_attr__( 'France', 'ninja-forms' ) => 'FR',
    esc_attr__( 'France, Metropolitan', 'ninja-forms' ) => 'FX',
    esc_attr__( 'French Guiana', 'ninja-forms' ) => 'GF',
    esc_attr__( 'French Polynesia', 'ninja-forms' ) => 'PF',
    esc_attr__( 'French Southern Territories', 'ninja-forms' ) => 'TF',
    esc_attr__( 'Gabon', 'ninja-forms' ) => 'GA',
    esc_attr__( 'Gambia', 'ninja-forms' ) => 'GM',
    esc_attr__( 'Georgia', 'ninja-forms' ) => 'GE',
    esc_attr__( 'Germany', 'ninja-forms' ) => 'DE',
    esc_attr__( 'Ghana', 'ninja-forms' ) => 'GH',
    esc_attr__( 'Gibraltar', 'ninja-forms' ) => 'GI',
    esc_attr__( 'Greece', 'ninja-forms' ) => 'GR',
    esc_attr__( 'Greenland', 'ninja-forms' ) => 'GL',
    esc_attr__( 'Grenada', 'ninja-forms' ) => 'GD',
    esc_attr__( 'Guadeloupe', 'ninja-forms' ) => 'GP',
    esc_attr__( 'Guam', 'ninja-forms' ) => 'GU',
    esc_attr__( 'Guatemala', 'ninja-forms' ) => 'GT',
    esc_attr__( 'Guinea', 'ninja-forms' ) => 'GN',
    esc_attr__( 'Guinea-Bissau', 'ninja-forms' ) => 'GW',
    esc_attr__( 'Guyana', 'ninja-forms' ) => 'GY',
    esc_attr__( 'Haiti', 'ninja-forms' ) => 'HT',
    esc_attr__( 'Heard And Mc Donald Islands', 'ninja-forms' ) => 'HM',
    esc_attr__( 'Holy See (Vatican City State)', 'ninja-forms' ) => 'VA',
    esc_attr__( 'Honduras', 'ninja-forms' ) => 'HN',
    esc_attr__( 'Hong Kong', 'ninja-forms' ) => 'HK',
    esc_attr__( 'Hungary', 'ninja-forms' ) => 'HU',
    esc_attr__( 'Iceland', 'ninja-forms' ) => 'IS',
    esc_attr__( 'India', 'ninja-forms' ) => 'IN',
    esc_attr__( 'Indonesia', 'ninja-forms' ) => 'ID',
    esc_attr__( 'Iran (Islamic Republic Of)', 'ninja-forms' ) => 'IR',
    esc_attr__( 'Iraq', 'ninja-forms' ) => 'IQ',
    esc_attr__( 'Ireland', 'ninja-forms' ) => 'IE',
    esc_attr__( 'Israel', 'ninja-forms' ) => 'IL',
    esc_attr__( 'Italy', 'ninja-forms' ) => 'IT',
    esc_attr__( 'Jamaica', 'ninja-forms' ) => 'JM',
    esc_attr__( 'Japan', 'ninja-forms' ) => 'JP',
    esc_attr__( 'Jordan', 'ninja-forms' ) => 'JO',
    esc_attr__( 'Kazakhstan', 'ninja-forms' ) => 'KZ',
    esc_attr__( 'Kenya', 'ninja-forms' ) => 'KE',
    esc_attr__( 'Kiribati', 'ninja-forms' ) => 'KI',
    esc_attr__( 'Korea, Democratic People\'s Republic Of', 'ninja-forms' ) => 'KP',
    esc_attr__( 'Korea, Republic Of', 'ninja-forms' ) => 'KR',
    esc_attr__( 'Kuwait', 'ninja-forms' ) => 'KW',
    esc_attr__( 'Kyrgyzstan', 'ninja-forms' ) => 'KG',
    esc_attr__( 'Lao People\'s Democratic Republic', 'ninja-forms' ) => 'LA',
    esc_attr__( 'Latvia', 'ninja-forms' ) => 'LV',
    esc_attr__( 'Lebanon', 'ninja-forms' ) => 'LB',
    esc_attr__( 'Lesotho', 'ninja-forms' ) => 'LS',
    esc_attr__( 'Liberia', 'ninja-forms' ) => 'LR',
    esc_attr__( 'Libyan Arab Jamahiriya', 'ninja-forms' ) => 'LY',
    esc_attr__( 'Liechtenstein', 'ninja-forms' ) => 'LI',
    esc_attr__( 'Lithuania', 'ninja-forms' ) => 'LT',
    esc_attr__( 'Luxembourg', 'ninja-forms' ) => 'LU',
    esc_attr__( 'Macau', 'ninja-forms' ) => 'MO',
    esc_attr__( 'Macedonia, Former Yugoslav Republic Of', 'ninja-forms' ) => 'MK',
    esc_attr__( 'Madagascar', 'ninja-forms' ) => 'MG',
    esc_attr__( 'Malawi', 'ninja-forms' ) => 'MW',
    esc_attr__( 'Malaysia', 'ninja-forms' ) => 'MY',
    esc_attr__( 'Maldives', 'ninja-forms' ) => 'MV',
    esc_attr__( 'Mali', 'ninja-forms' ) => 'ML',
    esc_attr__( 'Malta', 'ninja-forms' ) => 'MT',
    esc_attr__( 'Marshall Islands', 'ninja-forms' ) => 'MH',
    esc_attr__( 'Martinique', 'ninja-forms' ) => 'MQ',
    esc_attr__( 'Mauritania', 'ninja-forms' ) => 'MR',
    esc_attr__( 'Mauritius', 'ninja-forms' ) => 'MU',
    esc_attr__( 'Mayotte', 'ninja-forms' ) => 'YT',
    esc_attr__( 'Mexico', 'ninja-forms' ) => 'MX',
    esc_attr__( 'Micronesia, Federated States Of', 'ninja-forms' ) => 'FM',
    esc_attr__( 'Moldova, Republic Of', 'ninja-forms' ) => 'MD',
    esc_attr__( 'Monaco', 'ninja-forms' ) => 'MC',
    esc_attr__( 'Mongolia', 'ninja-forms' ) => 'MN',
    esc_attr__( 'Montenegro', 'ninja-forms' ) => 'ME',
    esc_attr__( 'Montserrat', 'ninja-forms' ) => 'MS',
    esc_attr__( 'Morocco', 'ninja-forms' ) => 'MA',
    esc_attr__( 'Mozambique', 'ninja-forms' ) => 'MZ',
    esc_attr__( 'Myanmar', 'ninja-forms' ) => 'MM',
    esc_attr__( 'Namibia', 'ninja-forms' ) => 'NA',
    esc_attr__( 'Nauru', 'ninja-forms' ) => 'NR',
    esc_attr__( 'Nepal', 'ninja-forms' ) => 'NP',
    esc_attr__( 'Netherlands', 'ninja-forms' ) => 'NL',
    esc_attr__( 'Netherlands Antilles', 'ninja-forms' ) => 'AN',
    esc_attr__( 'New Caledonia', 'ninja-forms' ) => 'NC',
    esc_attr__( 'New Zealand', 'ninja-forms' ) => 'NZ',
    esc_attr__( 'Nicaragua', 'ninja-forms' ) => 'NI',
    esc_attr__( 'Niger', 'ninja-forms' ) => 'NE',
    esc_attr__( 'Nigeria', 'ninja-forms' ) => 'NG',
    esc_attr__( 'Niue', 'ninja-forms' ) => 'NU',
    esc_attr__( 'Norfolk Island', 'ninja-forms' ) => 'NF',
    esc_attr__( 'Northern Mariana Islands', 'ninja-forms' ) => 'MP',
    esc_attr__( 'Norway', 'ninja-forms' ) => 'NO',
    esc_attr__( 'Oman', 'ninja-forms' ) => 'OM',
    esc_attr__( 'Pakistan', 'ninja-forms' ) => 'PK',
    esc_attr__( 'Palau', 'ninja-forms' ) => 'PW',
    esc_attr__( 'Panama', 'ninja-forms' ) => 'PA',
    esc_attr__( 'Papua New Guinea', 'ninja-forms' ) => 'PG',
    esc_attr__( 'Paraguay', 'ninja-forms' ) => 'PY',
    esc_attr__( 'Peru', 'ninja-forms' ) => 'PE',
    esc_attr__( 'Philippines', 'ninja-forms' ) => 'PH',
    esc_attr__( 'Pitcairn', 'ninja-forms' ) => 'PN',
    esc_attr__( 'Poland', 'ninja-forms' ) => 'PL',
    esc_attr__( 'Portugal', 'ninja-forms' ) => 'PT',
    esc_attr__( 'Puerto Rico', 'ninja-forms' ) => 'PR',
    esc_attr__( 'Qatar', 'ninja-forms' ) => 'QA',
    esc_attr__( 'Reunion', 'ninja-forms' ) => 'RE',
    esc_attr__( 'Romania', 'ninja-forms' ) => 'RO',
    esc_attr__( 'Russian Federation', 'ninja-forms' ) => 'RU',
    esc_attr__( 'Rwanda', 'ninja-forms' ) => 'RW',
    esc_attr__( 'Saint Kitts And Nevis', 'ninja-forms' ) => 'KN',
    esc_attr__( 'Saint Lucia', 'ninja-forms' ) => 'LC',
    esc_attr__( 'Saint Vincent And The Grenadines', 'ninja-forms' ) => 'VC',
    esc_attr__( 'Samoa', 'ninja-forms' ) => 'WS',
    esc_attr__( 'San Marino', 'ninja-forms' ) => 'SM',
    esc_attr__( 'Sao Tome And Principe', 'ninja-forms' ) => 'ST',
    esc_attr__( 'Saudi Arabia', 'ninja-forms' ) => 'SA',
    esc_attr__( 'Senegal', 'ninja-forms' ) => 'SN',
    esc_attr__( 'Serbia', 'ninja-forms' ) => 'RS',
    esc_attr__( 'Seychelles', 'ninja-forms' ) => 'SC',
    esc_attr__( 'Sierra Leone', 'ninja-forms' ) => 'SL',
    esc_attr__( 'Singapore', 'ninja-forms' ) => 'SG',
    esc_attr__( 'Slovakia (Slovak Republic)', 'ninja-forms' ) => 'SK',
    esc_attr__( 'Slovenia', 'ninja-forms' ) => 'SI',
    esc_attr__( 'Solomon Islands', 'ninja-forms' ) => 'SB',
    esc_attr__( 'Somalia', 'ninja-forms' ) => 'SO',
    esc_attr__( 'South Africa', 'ninja-forms' ) => 'ZA',
    esc_attr__( 'South Georgia, South Sandwich Islands', 'ninja-forms' ) => 'GS',
    esc_attr__( 'Spain', 'ninja-forms' ) => 'ES',
    esc_attr__( 'Sri Lanka', 'ninja-forms' ) => 'LK',
    esc_attr__( 'St. Helena', 'ninja-forms' ) => 'SH',
    esc_attr__( 'St. Pierre And Miquelon', 'ninja-forms' ) => 'PM',
    esc_attr__( 'Sudan', 'ninja-forms' ) => 'SD',
    esc_attr__( 'Suriname', 'ninja-forms' ) => 'SR',
    esc_attr__( 'Svalbard And Jan Mayen Islands', 'ninja-forms' ) => 'SJ',
    esc_attr__( 'Swaziland', 'ninja-forms' ) => 'SZ',
    esc_attr__( 'Sweden', 'ninja-forms' ) => 'SE',
    esc_attr__( 'Switzerland', 'ninja-forms' ) => 'CH',
    esc_attr__( 'Syrian Arab Republic', 'ninja-forms' ) => 'SY',
    esc_attr__( 'Taiwan', 'ninja-forms' ) => 'TW',
    esc_attr__( 'Tajikistan', 'ninja-forms' ) => 'TJ',
    esc_attr__( 'Tanzania, United Republic Of', 'ninja-forms' ) => 'TZ',
    esc_attr__( 'Thailand', 'ninja-forms' ) => 'TH',
    esc_attr__( 'Togo', 'ninja-forms' ) => 'TG',
    esc_attr__( 'Tokelau', 'ninja-forms' ) => 'TK',
    esc_attr__( 'Tonga', 'ninja-forms' ) => 'TO',
    esc_attr__( 'Trinidad And Tobago', 'ninja-forms' ) => 'TT',
    esc_attr__( 'Tunisia', 'ninja-forms' ) => 'TN',
    esc_attr__( 'Turkey', 'ninja-forms' ) => 'TR',
    esc_attr__( 'Turkmenistan', 'ninja-forms' ) => 'TM',
    esc_attr__( 'Turks And Caicos Islands', 'ninja-forms' ) => 'TC',
    esc_attr__( 'Tuvalu', 'ninja-forms' ) => 'TV',
    esc_attr__( 'Uganda', 'ninja-forms' ) => 'UG',
    esc_attr__( 'Ukraine', 'ninja-forms' ) => 'UA',
    esc_attr__( 'United Arab Emirates', 'ninja-forms' ) => 'AE',
    esc_attr__( 'United Kingdom', 'ninja-forms' ) => 'GB',
    esc_attr__( 'United States', 'ninja-forms' ) => 'US',
    esc_attr__( 'United States Minor Outlying Islands', 'ninja-forms' ) => 'UM',
    esc_attr__( 'Uruguay', 'ninja-forms' ) => 'UY',
    esc_attr__( 'Uzbekistan', 'ninja-forms' ) => 'UZ',
    esc_attr__( 'Vanuatu', 'ninja-forms' ) => 'VU',
    esc_attr__( 'Venezuela', 'ninja-forms' ) => 'VE',
    esc_attr__( 'Viet Nam', 'ninja-forms' ) => 'VN',
    esc_attr__( 'Virgin Islands (British)', 'ninja-forms' ) => 'VG',
    esc_attr__( 'Virgin Islands (U.S.)', 'ninja-forms' ) => 'VI',
    esc_attr__( 'Wallis And Futuna Islands', 'ninja-forms' ) => 'WF',
    esc_attr__( 'Western Sahara', 'ninja-forms' ) => 'EH',
    esc_attr__( 'Yemen', 'ninja-forms' ) => 'YE',
    esc_attr__( 'Yugoslavia', 'ninja-forms' ) => 'YU',
    esc_attr__( 'Zambia', 'ninja-forms' ) => 'ZM',
    esc_attr__( 'Zimbabwe', 'ninja-forms' ) => 'ZW'

));