<script id="tmpl-nf-field-listradio" type="text/template">
    <ul aria-describedby="nf-error-{{{ data.id }}}">
        {{{ data.renderOptions() }}}
    </ul>
</script>

<script id='tmpl-nf-field-listradio-option' type='text/template'>
    <# if ( ! data.visible ) { return '' } #>
    <li>
        <input type="radio"
               id="nf-field-{{{ data.fieldID }}}-{{{ data.index }}}"
               name="nf-field-{{{ data.fieldID }}}"
               class="{{{ data.classes }}} nf-element {{{ ( data.value == data.currentValue  || 1 == data.selected ) ? 'nf-checked' : '' }}}" value="{{{ data.value }}}" {{{ ( data.value == data.currentValue  || 1 == data.selected ) ? 'checked="checked"' : '' }}}
            aria-labelledby="nf-label-class-field-{{{ data.fieldID }}}-{{{ data.index }}}"
            <# if( data.required ) { #>
			required
			<# } #>
        >
        <label for="nf-field-{{{ data.fieldID }}}-{{{ data.index }}}"
               id="nf-label-class-field-{{{ data.fieldID }}}-{{{ data.index }}}" class="{{{ ( data.value == data.currentValue  || 1
                       ==
               data.selected ) ? 'nf-checked-label' : '' }}}">{{{ data.label }}}</label>
    </li>
</script>

<script id='tmpl-nf-field-listradio-other' type='text/template'>
    <li>
        <input type="radio" name="nf-field-{{{ data.fieldID }}}" class="{{{ data.classes }}} nf-element" value="nf-other" {{{ ( ! data.valueFound ) ? 'checked="checked"' : '' }}}> <label>Other {{{ data.renderOtherText() }}}</label>
    </li>
</script>

<script id='tmpl-nf-field-listradio-other-text' type='text/template'>
    <input type="text" name="nf-field-{{{ data.fieldID }}}" class="nf-element" value="{{{ data.currentValue }}}">
</script>
