<script id="tmpl-nf-field-repeater" type="text/template">

    <div id="nf-field-{{{ data.id }}}" 
        class="nf-repeater nf-repeater-fieldsets {{{ data.element_class }}}"
        data-field-id="{{{ data.id }}}"
    >
    </div>
    <button type="button" class="nf-add-fieldset">{{{nfRepeater.add_repeater_child_field_text}}} {{{data.label}}}</button>
    <div>{{{ data.description }}}</div>
    
</script>

<script id="tmpl-nf-field-repeater-set" type="text/template">

    <legend>{{{ data.label }}} {{{ data.index }}}</legend>
    <# if(data.index > 1 ) { #>
    <button class="nf-remove-fieldset" type="button" title="Remove Fieldset">&times;</button>
    <# } #>
    <div class="nf-repeater-fieldset" ></div>

</script>
