<div id="nf-header">
    <div id="nf-app-header">
        <div id="nf-logo"></div>
        <ul>
            <li><a href="#"><?php esc_html_e( 'Form Fields', 'ninja-forms' ); ?></a></li>
            <li><a href="#"><?php esc_html_e( 'Emails & Actions', 'ninja-forms' ); ?></a></li>
            <li><a href="#"><?php esc_html_e( 'Settings', 'ninja-forms' ); ?></a></li>
            <li><a class="preview" href="#"><?php esc_html_e( 'Preview Changes', 'ninja-forms' ); ?><span class="dashicons dashicons-visibility"></span></a></li>
        </ul>
        <input class="nf-button primary" type="submit" value="Save" />
        <a class="nf-mobile" href="#"><span class="dashicons dashicons-editor-ul"></span></a>
        <a class="nf-cancel" href="#"><?php esc_html_e( 'Cancel', 'ninja-forms' ); ?></a>
    </div>

    <div id="nf-app-sub-header">

        <a class="nf-add-new" href="#"><?php esc_html_e( 'Add new field', 'ninja-forms' ); ?></a>
        <h2><?php esc_html_e( 'Contact Form', 'ninja-forms' ); ?></h2>

        <!-- <input class="nf-button secondary" type="submit" value="Edit Emails and Actions" /> -->

    </div>

</div>
