<script id="tmpl-nf-field-date" type="text/template">
	<div class="pikaday__container"><!-- Pikaday mentions were added for backwards compatibility -->
		<input id="nf-field-{{{ data.id }}}" name="nf-field-{{{ data.id }}}" aria-invalid="false" aria-describedby="nf-error-{{{ data.id }}}" class="{{{ data.renderClasses() }}} nf-element datepicker pikaday__display pikaday__display--pikaday"
			aria-labelledby="nf-label-field-{{{ data.id }}}"
				{{{ data.maybeRequired() }}}
			type="date" value="{{{ data.value }}}" {{{ data.renderPlaceholder() }}}>
	</div>
</script>
