<?php if ( ! defined( 'ABSPATH' ) ) exit;

return apply_filters( 'ninja_forms_currency', array(
    'AUD' => array(
        'label' => esc_attr__( 'Australian Dollars', 'ninja-forms' ),
        'value' => 'AUD'
    ),
    'CAD' => array(
        'label' => esc_attr__( 'Canadian Dollars', 'ninja-forms' ),
        'value' => 'CAD'
    ),
    'CZK' => array(
        'label' => esc_attr__( 'Czech Koruna', 'ninja-forms' ),
        'value' => 'CZK'
    ),
    'DKK' => array(
        'label' => esc_attr__( 'Danish Krone', 'ninja-forms' ),
        'value' => 'DKK'
    ),
    'EUR' => array(
        'label' => esc_attr__( 'Euros', 'ninja-forms' ),
        'value' => 'EUR'
    ),
    'HKD' => array(
        'label' => esc_attr__( 'Hong Kong Dollars', 'ninja-forms' ),
        'value' => 'HKD'
    ),
    'HUF' => array(
        'label' => esc_attr__( 'Hungarian Forints', 'ninja-forms' ),
        'value' => 'HUF'
    ),
    'ILS' => array(
        'label' => esc_attr__( 'Israeli New Sheqels', 'ninja-forms' ),
        'value' => 'ILS'
    ),
    'JPY' => array(
        'label' => esc_attr__( 'Japanese Yen', 'ninja-forms' ),
        'value' => 'JPY'
    ),
    'MXN' => array(
        'label' => esc_attr__( 'Mexican Pesos', 'ninja-forms' ),
        'value' => 'MXN'
    ),
    'MYR' => array(
        'label' => esc_attr__( 'Malaysian Ringgit', 'ninja-forms' ),
        'value' => 'MYR'
    ),
    'NOK' => array(
        'label' => esc_attr__( 'Norwegian Krone', 'ninja-forms' ),
        'value' => 'NOK'
    ),
    'NZD' => array(
        'label' => esc_attr__( 'New Zealand Dollars', 'ninja-forms' ),
        'value' => 'NZD'
    ),
    'PHP' => array(
        'label' => esc_attr__( 'Philippine Pesos', 'ninja-forms' ),
        'value' => 'PHP'
    ),
    'PLN' => array(
        'label' => esc_attr__( 'Polish Zloty', 'ninja-forms' ),
        'value' => 'PLN'
    ),
    'GBP' => array(
        'label' => esc_attr__( 'British Pounds Sterling', 'ninja-forms' ),
        'value' => 'GBP'
    ),
    'SGD' => array(
        'label' => esc_attr__( 'Singapore Dollars', 'ninja-forms' ),
        'value' => 'SGD'
    ),
    'SEK' => array(
        'label' => esc_attr__( 'Swedish Krona', 'ninja-forms' ),
        'value' => 'SEK'
    ),
    'CHF' => array(
        'label' => esc_attr__( 'Swiss Franc', 'ninja-forms' ),
        'value' => 'CHF'
    ),
    'TWD' => array(
        'label' => esc_attr__( 'Taiwan New Dollars', 'ninja-forms' ),
        'value' => 'TWD'
    ),
    'THB' => array(
        'label' => esc_attr__( 'Thai Baht', 'ninja-forms' ),
        'value' => 'THB'
    ),
    'USD' => array(
        'label' => esc_attr__( 'U.S. Dollars', 'ninja-forms' ),
        'value' => 'USD'
    ),
    'ZAR' => array(
        'label' => esc_attr__( 'South African Rand', 'ninja-forms' ),
        'value' => 'ZAR'
    ),
	'INR' => array(
		'label' => esc_attr__( 'Indian Rupee', 'ninja-forms' ),
		'value' => 'INR'
    ),
    'RUB' => array(
        'label' => esc_attr__( 'Russian Ruble', 'ninja-forms' ),
        'value' => 'RUB'
    ),
    'CNY' => array(
        'label' => esc_attr__( 'Chinese Yuan', 'ninja-forms' ),
        'value' => 'CNY'
    )
));