<script id="tmpl-nf-form-layout" type="text/template">
	<form>
		<div>
			<div class="nf-before-form-content"></div>
			<div class="nf-form-content {{{ data.element_class }}}"></div>
			<div class="nf-after-form-content"></div>
		</div>
	</form>
</script>