.ninja-forms-settings h3.hndle {
    padding: 10px 12px;
    margin: 0;
}

.nf-loading-spinner {
    width: 40px;
    height: 40px;
    margin: 15px auto;
    background-color: rgba(208,208,208,.5);

    border-radius: 100%;
    animation: nf-scaleout 1.0s infinite ease-in-out;
}

@-webkit-keyframes nf-scaleout {
    0% { transform: scale(0) }
    100% {
        transform: scale(1.0);
        opacity: 0;
    }
}

@keyframes nf-scaleout {
    0% {
        transform: scale(0);
    } 100% {
          transform: scale(1.0);
          opacity: 0;
      }
}


.ninja-forms-settings .postbox .item-controls {
    display: none;
}

.nf_export_input {
    width: 60%;
}

.nf_filter_sub_input {
    width: 159px;
}
.nf-form-dropdown {
    display:none;
    border: 1px solid black;
    background-color: lightgrey;
    position: absolute;
    max-height: 150px;
    overflow: auto;
    width: 60%;
}

.nf-form-option:hover {
    background-color: #0073aa;
    color: #FFFFFF;
    cursor: pointer;
}

.nf-form-option {
    padding: 4px;
    border-bottom: 1px solid black;
    margin-bottom: 0;
}

.alignleft.actions input[type=text] {
    height: 28px;
    border-radius: 4px;
}

.jBox-content {
    overflow: hidden !important;
}

@media screen and ( max-width: 782px ) {
    .tablenav.top .actions, .tablenav .view-switch {
        display:block;
    }
}
