<script id="tmpl-nf-field-listselect" type="text/template">
    <select id="nf-field-{{{ data.id }}}" name="nf-field-{{{ data.id }}}" aria-invalid="false" aria-describedby="nf-error-{{{ data.id }}}" class="{{{ data.renderClasses() }}} nf-element" {{{ data.renderOtherAttributes() }}}
            aria-labelledby="nf-label-field-{{{ data.id }}}"

	    {{{ data.maybeRequired() }}}
    >
        {{{ data.renderOptions() }}}
    </select>
    <div></div>
</script>

<script id="tmpl-nf-field-listselect-option" type="text/template">
	<# if ( ! data.visible ) { return ''; } #>
	<option value="{{{ data.value }}}" {{{ ( 1 == data.selected ) ? 'selected="selected"' : '' }}} >{{{ data.label }}}</option>
</script>
