.nf-box {
    background: #fff;
    border: 1px solid #ccc;
    border-radius: 4px;
    display: inline-block;
    padding: 20px;
}

#debug-report {
    display: none;
}
#debug-report textarea {
    height: 200px;
    width: 300px;
}
.debug-report {
    display: inline-block;
    padding: 0;
}
.debug-report h3:first-child {
    margin-top: 0;
}

.nf-status-table {
    background: #f1f1f1;
    border-radius: 4px 4px 0 0;
    margin-right: 20px;
    max-width: 1150px;
}
.nf-status-table th {
    border-color: #ccc;
    border-style: solid;
    border-width: 1px 1px 0 1px;
    border-radius: 4px 4px 0 0;
    font-size: 1.4em;
    font-weight: normal;
    padding: .5em 0;
    width: 100%;
}
.nf-status-table thead:first-child th {
    border-radius: 4px 4px 0 0;
}
.nf-status-table td {
    border-color: #ccc;
    border-style: solid;
    border-width: 1px 1px 0px 1px;
    padding: .5em;
}
.nf-status-table td:first-child {
    border-left: 1px solid #ccc;
    border-right-width: 0;
    min-width: 200px;
}
.nf-status-table tbody:last-child td {
    border-bottom-width: 1px;
}

.jBox-content {
    font-size: 28px;
    padding: 40px !important;
}
