.nf-admin-notice {
    color: white;
    background: #ED494D;
    border-color: #ED494D;
    border-top: 4px;
    display: block;
    min-height: 68px;
    padding: 10px 40px 10px 145px;
    position: relative;
}
.nf-notice-container {
    margin-left: 20px;
}
.nf-admin-notice a {
    color: white;
    background-color: #3b454d;
    text-decoration: none;
    padding: 5px 10px;
    border-radius: 5px;
}
.nf-notice-logo {
    clear: both;
    content: "";
    display: block;
    background-image: url("../img/ninja-forms-app-header-logo@2x.png");
    background-size: 160px 60px;
    background-repeat: no-repeat;
    background-position: 0 100%;
    width: 160px;
    position: absolute;
    top: 0;
    bottom: 0;
    left: 5px;
}
.nf-admin-notice > .dashicons {
    color: white;
    background-color: transparent;
    position: absolute;
    right: 20px;
    top: 40%;
}
.nf-notice-title {
    font-size: 20px;
    font-weight: bold;
}
.nf-notice-links {
    margin: 0;
}
.nf-notice-links li {
    display: inline-block;
}
.nf-notice-body {
    font-weight: normal;
    margin: 5px 0 10px;
}
.nf-notice-body:after {
    clear: both;
    content: "";
    display: block;
}
.nf-notice-body li {
    float: left;
    margin-right: 20px;
}
.nf-notice-body .dashicons {
    font-size: 17px;
}
.nf-red {
    color: #ED494D;
}
.nf-admin-error {
    border-left: 5px solid #ED494D;
}
.nf-admin-error .nf-notice-title {
    color: #ED494D;
}

.nf-admin-error .nf-notice-title,
.nf-admin-error .nf-notice-body {
    margin: 10px 0 10px 130px;
}
